package users

import (
	"context"
	"encoding/json"
	"net/http"
	"net/url"

	"github.com/google/go-querystring/query"
)

type UpdateUserParams struct {
	// The string to update the channel’s description to. The description is limited to a maximum of 300 characters.
	//
	// To remove the description, specify this parameter but don’t set it’s value (for example, ?description=).
	Description *string `url:"description,omitempty"`
}

type UpdateUserResponse struct {
	// A list contains the single user that you updated.
	Data []User `json:"data"`
}

// Updates the specified user’s information. The user ID in the OAuth token identifies the user whose information you want to update.
//
// To include the user’s verified email address in the response, the user access token must also include the user:read:email scope.
//
// Requires a user access token that includes the user:edit scope.
func (u *Users) UpdateUser(ctx context.Context, params *UpdateUserParams) (*UpdateUserResponse, error) {
	v, _ := query.Values(params)
	endpoint := u.baseUrl.ResolveReference(&url.URL{Path: "users", RawQuery: v.Encode()})

	req, err := http.NewRequestWithContext(ctx, http.MethodPatch, endpoint.String(), nil)
	if err != nil {
		return nil, err
	}

	res, err := u.client.Do(req)
	if err != nil {
		return nil, err
	}
	defer res.Body.Close()

	var data UpdateUserResponse
	if err := json.NewDecoder(res.Body).Decode(&data); err != nil {
		return nil, err
	}

	return &data, nil
}
